@@ -20,5 +20,11 @@ BEGIN {
 
 require Judy; # Beware, Judy.pm also loads Judy::1.
 
+require Judy::_obj;
+Judy::_obj->import( -impl );
+
+require Judy::1::_tie;
+require Judy::1::_obj;
+
 no warnings;
 'Warning! The consumption of alcohol may cause you to think you have mystical kung-fu powers.'
